# Tinyml

> The machine learning framework implemented in pure python.

![Build](https://github.com/xzyaoi/tinyml/workflows/Test%20Coveralls/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/xzyaoi/tinyml/badge.svg)](https://coveralls.io/github/xzyaoi/tinyml)

## Documents.

[Online Documents](https://tinynet.autoai.org)
